[PyPI](https://pypi.org/project/neuroboros/) | [GitHub](https://github.com/neuroboros/neuroboros) | [Issues](https://github.com/neuroboros/neuroboros/issues)

`neuroboros` is a Python package for neuroimaging data analysis. It is under active development, and the API might differ across versions.
